@@ -49,18 +49,18 @@ class Hash(BaseModel):
     """
     Контрольные суммы по алгоритму SHA1
     """
-    format: StrictStr = Field(
+    format: str = Field(
         title="Идентификатор формата файла DBF",
         description="Высчитывается из набора колонок файла DBF (columns). "
                     "Выражает тип DBF в независимости от источника получения файла. "
                     "Может случить идентификатором набора колонок и их типов.",
-        example="da58e0c8b7a42981282358c43c15b1d7004deaf4")
-    source: Optional[StrictStr] = Field(
+        example="da58e0c8b7a42981282358c43c15b1d7004deaf4", regex="^[0-9a-f]{40}$")
+    source: Optional[str] = Field(
         title="Идентификатор источника данных DBF",
         description="Высчитывается из набора колонок файла DBF (columns) и источника получения файла (url). "
                     "Так как одинаковые форматы DBF могут нести разную прикландую информцию, необходимо точно "
                     "идентифицировать формат файла. Не только по структуре, но и по ее применяемости.",
-        example="4e38e02213ec9307ca5cd2bdd3ad9b05f0d24e7a")
+        example="4e38e02213ec9307ca5cd2bdd3ad9b05f0d24e7a", regex="^[0-9a-f]{40}$")
 
     class Config(BaseConfig):
         title = "Идентификаторы файла DBF"
@@ -79,8 +79,7 @@ class FormatPacket(BaseModel):
         title = "Формат файла DBF"
 
 
-RowValueType = TypeVar('RowValueType', StrictStr, StrictInt, StrictFloat,
-                       StrictBool, datetime, date)
+RowValueType = TypeVar('RowValueType', StrictStr, StrictInt, StrictFloat, StrictBool, datetime, date)
 
 
 class Packet(Hash):
@@ -91,14 +90,14 @@ class Packet(Hash):
 
     class File(BaseModel):
         name: StrictStr = Field(title="Имя загруженного файла")
-        hash: StrictStr = Field(title="Хеш файла по алгоритму SHA1",
-                                example="65188ac21abf3198780ebab1cefb005c12958afb")
+        hash: str = Field(title="Хеш файла по алгоритму SHA1",
+                                example="65188AC21ABF3198780EBAB1CEFD005C12958AFB", regex="^[0-9A-F]{40}$")
         modify: date = Field(title="Дата модификации файла DBF",
                              description="Берется из заголовка самого файла, "
                                          "не имеет значения зафиксированное время изменнения, "
                                          "полученое из файловой системы")
         url: Optional[Source]
-        hex: StrictStr = Field(title="Содержимое файла в виде HEX строки")
+        hex: str = Field(title="Содержимое файла в виде HEX строки", regex="^[0-9A-F]{2,}$")
 
         class Config(BaseConfig):
             title = "Описание загруженного файла DBF"
