@@ -1,4 +1,5 @@
-from pydantic import BaseModel, StrictStr
+from pydantic import BaseModel, StrictStr, Field
+
 from bssapi_schemas import exch
 
 
@@ -6,8 +7,8 @@ class PacketsOfTabDataSources(BaseModel):
     """
     Примесь описания источника данных
     """
-    Hash: StrictStr
-    Format: StrictStr
+    Hash: str = Field(regex="^[0-9a-f]{40}$")
+    Format: str = Field(regex="^[0-9a-f]{40}$")
     Packet: exch.FormatPacket
 
 
@@ -15,6 +16,7 @@ class PacketsOfTabData(BaseModel):
     """
     Примесь описания пакета данных
     """
+    Hash: str = Field(regex="^[0-9A-F]{40}$")
     FileName: StrictStr
-    Source: StrictStr
+    Source: str = Field(regex="^[0-9a-f]{40}$")
     Packet: exch.Packet
